diff src/load-save.cc @ 3531:97cf542676e1

[project @ 2000-02-02 11:30:40 by jwe]
author jwe
date Wed, 02 Feb 2000 11:33:32 +0000
parents b80bbb43a1a9
children e8fbc8c3d6d9
line wrap: on
line diff
--- a/src/load-save.cc	Wed Feb 02 11:18:39 2000 +0000
+++ b/src/load-save.cc	Wed Feb 02 11:33:32 2000 +0000
@@ -1803,11 +1803,11 @@
       if (format != LS_UNKNOWN)
 	{
 	  // XXX FIXME XXX -- if we have already seen EOF on a
-	  // previous call, how do we fix up the state of cin so that
-	  // we can get additional input?  I'm afraid that we can't
-	  // fix this using cin only.
-
-	  retval = do_load (cin, orig_fname, force, format, flt_fmt,
+	  // previous call, how do we fix up the state of std::cin so
+	  // that we can get additional input?  I'm afraid that we
+	  // can't fix this using std::cin only.
+
+	  retval = do_load (std::cin, orig_fname, force, format, flt_fmt,
 			    list_only, swap, verbose, argv, i, argc,
 			    nargout);
 	}